pynrc.reduce.calib
==================

.. automodule:: pynrc.reduce.calib

   
   
   

   
   
   .. rubric:: Functions

   .. autosummary::
      :toctree:
   
      apply_linearity
      apply_nonlin
      broken_pink_powspec
      calc_cdsnoise
      calc_eff_noise
      calc_ktc
      calc_linearity_coeff
      calc_nonlin_coeff
      chisqr_red
      cube_fit
      deconv_single_image
      detname_to_scaid
      find_group_sat
      find_sat
      fit_corr_powspec
      fit_func_var_ex
      gen_cds_dict
      gen_col_variations
      gen_ref_dict
      gen_super_bias
      gen_super_dark
      gen_super_ramp
      get_bias_offsets
      get_fits_data
      get_flat_fields
      get_freq_array
      get_ipc_kernel
      get_linear_coeffs
      get_oddeven_offsets
      get_power_spec
      get_power_spec_all
      get_ref_instability
      ipc_deconvolve
      pixel_linearity_gains
      plot_dark_histogram
      plot_kernel
      pow_spec_ramp
      pow_spec_ramp_pix
      ppc_deconvolve
      ramp_derivative
      ramp_resample
      time_to_sat
   
   

   
   
   .. rubric:: Classes

   .. autosummary::
      :toctree:
      :template: custom-class-template.rst
   
      nircam_cal
      nircam_dark
   
   

   
   
   



